﻿//----------------------------------------------------------------------
// SOAP client example, Sipwise GmbH, v1.0
//----------------------------------------------------------------------
// NOTE: How to deal with errors in Reference.cs:
// As a workaround you should modify the error block(s)
// From:
// public int id 
// {
// ...
// 
// To:
// [XmlElement("id")]
// public int Id 
// {
// ...
//
//----------------------------------------------------------------------
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using SoapClient.Provisioning;

namespace SoapClient
{
    class Program
    {
        static void Main(string[] args)
        {
            Console.WriteLine("SOAP client started.");
            MyInterface iface = new MyInterface();
             
            Console.WriteLine("Fetching domains list.");

            DomainRead[] domains = iface.Request.get_domains(iface.Auth);
            int domainsLength = domains.GetLength(0);
            for (int idx=0;idx<domainsLength;idx++) 
            {
                DomainRead item = domains[idx];
                Console.WriteLine(string.Format("domain{0}: {1}", idx+1, item.domain));
            }

            if (domainsLength > 0)
            {
                string domain = domains[0].domain;
                Console.WriteLine("Creating an account.");
                CreateVoIPAccountParameter accCreateParams = new CreateVoIPAccountParameter();
                accCreateParams.data = new VoipAccountCreate();
                accCreateParams.data.billing_profile = "default";
                int accountId = iface.create_voip_account(iface.Auth, accCreateParams);
                Console.WriteLine("Created account: " + accountId.ToString());

                string subscriberName = "soaptest";
                Console.WriteLine("Creating subscriber " + subscriberName + "@" + domain);
                WriteSubscriberParameter addSubscriberParams = new WriteSubscriberParameter();
                addSubscriberParams.id = accountId;
                addSubscriberParams.subscriber = new SubscriberWrite();
                addSubscriberParams.subscriber.username = "soaptest";
                addSubscriberParams.subscriber.password = "soaptest123456";
                addSubscriberParams.subscriber.domain = domain;
                iface.add_voip_account_subscriber(iface.Auth, addSubscriberParams);
                Console.WriteLine("Created subscriber " + subscriberName + "@" + domain);

                Console.WriteLine("-- subscriber's preferences set");
                Console.WriteLine("--   'ac' -> '43'");
                Console.WriteLine("--   'sst_enable' -> 'yes'");
                SetSubscriberPreferencesParameter subscriberPrefs = new SetSubscriberPreferencesParameter();
                subscriberPrefs.preferences = new SubscriberPreferencesWrite();
                subscriberPrefs.username = subscriberName;
                subscriberPrefs.domain = domain;
                subscriberPrefs.preferences.ac = "43";
                subscriberPrefs.preferences.sst_enable = sst_enable_usrEnum.yes; /* = null; # to set it to domain's default */
                subscriberPrefs.preferences.sst_enableSpecified = true;
                iface.set_subscriber_preferences(iface.Auth, subscriberPrefs);

                Console.WriteLine("-- subscriber's preferences get");
                UserDomParameter subscriber = new UserDomParameter();
                subscriber.username = subscriberName;
                subscriber.domain = domain;
                SubscriberPreferencesRead prefs = iface.get_subscriber_preferences(iface.Auth, subscriber);
                Console.WriteLine("ac: " + prefs.ac);
                Console.WriteLine("sst_enable: " + prefs.sst_enable);

                Console.WriteLine("Removing account: " + accountId.ToString());
                AccountIdParameter accDeleteParams = new AccountIdParameter();
                accDeleteParams.id = accountId;
                iface.delete_voip_account(iface.Auth, accDeleteParams);
                Console.WriteLine("Account was removed.");
            }

            Console.WriteLine("\n\n\nPress any key to close");
            Console.ReadKey();
        }
    }
}
