#!/usr/bin/php
<?php
//----------------------------------------------------------------------
// SOAP client example, Sipwise GmbH, v1.0
//----------------------------------------------------------------------
require 'nusoap/nusoap.php' ;

$http_username = 'ngcpsoap';
$http_password = 's04pt3st';
$auth_username = 'administrator';
$auth_password = 'administrator';
$hostname      = '10.20.30.40';

print "SOAP client started.\n";

# https connection
$client = new nusoap_client('https://'.$hostname.':2443/SOAP/Provisioning.wsdl',
                             true);
$client->setCredentials($http_username, $http_password, 'basic');
$error = $client->getError();
if ($error) {
    die("Error: $error\n");
}

# authentication
$auth = array( 'authentication' => array( 'type'     => 'admin',
                                          'username' => $auth_username, 
                                          'password' => $auth_password 
                                        )
             );

# get domains
print "Fetching domains list.\n";
$domains = $client->call('get_domains', $auth);
if ($client->getError())
    die("Error: ".$client->faultstring."\n");
if (sizeof($domains) <= 0)
    exit(1);
foreach ($domains as &$row)
    print $row['domain']."\n";

# create a temporary account
print "Creating an account.\n";
$params = array( 'parameters' => 
            array( 'data' => 
                array( 'billing_profile' => 'default' )
                 )
               );
$account_id = $client->call('create_voip_account', $auth + $params);
if ($client->getError())
    die("Error: ".$client->faultstring."\n");
printf("Created account: %d\n", $account_id);

# create a temporary subscriber
$subscriber_name = 'soaptest';
$domain_name     = $domains[0]['domain'];
printf("Creating subscriber %s@%s\n", $subscriber_name, $domain_name);
$params = array( 'parameters' => 
            array( 'id' => $account_id,
                   'subscriber' => array(
                        'username' => $subscriber_name,
                        'password' => 'soaptest123456',
                        'domain'   => $domain_name
                   )
                 )
               );
$client->call('add_voip_account_subscriber', $auth + $params);
if ($client->getError())
    die("Error: ".$client->faultstring."\n");
printf("Created subscriber %s@%s\n", $subscriber_name, $domain_name);

# get/set susbcriber's preferences
print "-- subscriber's preferences set\n";
print "--   'ac' -> '43'\n";
print "--   'sst_enable' -> 'yes'\n";
$params = array( 'parameters' => array(
                    'username' => $subscriber_name,
                    'domain'   => $domain_name,
                    'preferences' => array(
                        'ac'         => 43,
                        'sst_enable' => 'yes' # null - to set back to default
                    )
                 )
               );
$client->call('set_subscriber_preferences', $auth + $params);
if ($client->getError())
    die("Error: ".$client->faultstring."\n");

print("-- subscriber's preferences get\n");
$params = array( 'parameters' => array(
                    'username' => $subscriber_name,
                    'domain'   => $domain_name,
                 )
               );
$subscriber_prefs = $client->call('get_subscriber_preferences',
                                    $auth + $params);
printf("-- ac: %s\n", $subscriber_prefs['ac']);
printf("-- sst_enable: %s\n", $subscriber_prefs['sst_enable']);

# delete the created account
printf("Removing account %d\n", $account_id);
$params = array( 'parameters' => array(
                    'id' => $account_id
                 )
               );
$client->call('delete_voip_account', $auth + $params);
print("Account was removed.\n");

exit(0);

?>
