#!/usr/bin/perl -w
#----------------------------------------------------------------------
# SOAP client example, Sipwise GmbH, v1.0
#----------------------------------------------------------------------
package MySOAPClient;
use strict;
use SOAP::Lite;
#use SOAP::Lite +trace => [qw(debug)];
use MIME::Base64 qw(encode_base64);
use Data::Dumper;
BEGIN {
	$ENV{PERL_LWP_SSL_VERIFY_HOSTNAME} = 0;
}
#----------------------------------------------------------------------
my $http_user = 'ngcpsoap';
my $http_pass = 's04pt3st';
my $soap_user = 'administrator';
my $soap_pass = 'administrator';
my $hostname  = '10.20.30.40';
#----------------------------------------------------------------------
sub new {
	my $class = shift;
	my $opts = shift;
    my $self = {};
	return $class if ref $class;

	my $http_authz = 'Basic '.encode_base64($http_user.':'.$http_pass);
	$self->{auth}  = SOAP::Data->name(authentication => { type     => "admin",
                                               	   		  username => $soap_user,
                                               	   		  password => $soap_pass });
	my $soap = SOAP::Lite
  					-> uri('/SOAP/Provisioning')
  					-> proxy('https://'.$hostname.':2443/SOAP');
	$soap->transport->http_request->headers->push_header('Authorization' => $http_authz);

	$self->{soap} = $soap;

    return bless $self, $class;
}
#----------------------------------------------------------------------
sub soap_call {
	my $self = shift;
	my $method = shift;
	my @args = @_;

	my $res = $self->{soap}->call($method, $self->{auth}, @args);

	if	($res->fault) {
		printf "Error: %s\n", $res->faultstring;
        exit 1;
	} else {
		return $res->result;
	}
}

print "SOAP client started.\n";

my $client = new MySOAPClient;

# get domains
my $domains = $client->soap_call('get_domains');
foreach my $row (@$domains) {
    printf "domain: %s\n", $row->{domain};
}
exit 1 if $#$domains < 0;

# create a temporary account
print "Creating an account\n";
my $params = SOAP::Data->name(parameters => { 
                                data => {
                                    billing_profile => 'default' 
                                }
                              });
my $account_id = $client->soap_call('create_voip_account', $params);
printf "Created account: %d\n", $account_id;

# create a temporary subscriber
my $subscriber_name = 'soaptest';
my $domain_name = $domains->[0]{domain};
printf "Creating subscriber %s@%s\n", $subscriber_name, $domain_name;
$params = SOAP::Data->name(parameters => { 
                                id => $account_id,
                                subscriber => {
                                            username => $subscriber_name,
                                            password => 'soaptest123456',
                                            domain   => $domain_name,
                                }
                           });
$client->soap_call('add_voip_account_subscriber', $params);
printf "Created subscriber %s@%s\n", $subscriber_name, $domain_name;

# get/set subscriber's preferences
print "-- subscriber's preferences set\n";
print "--   'ac' -> '43'\n";
print "--   'sst_enable' -> 'yes'\n";
$params = SOAP::Data->name(parameters => { 
                                username => $subscriber_name,
                                domain   => $domain_name,
							    preferences => { 
                                                ac => 43, 
                                                sst_enable => 'yes' # undef - to set back to default
                                }
						   });
$client->soap_call('set_subscriber_preferences', $params);

print "-- subscriber's preferences get\n";
$params = SOAP::Data->name(parameters => { 
                                username => $subscriber_name,
                                domain   => $domain_name,
						   });
my $subscriber_prefs = $client->soap_call('get_subscriber_preferences', 
                                            $params);
printf "-- ac: %s\n", $subscriber_prefs->{ac};
printf "-- sst_enable: %s\n", $subscriber_prefs->{sst_enable} || 'undef';

# delete the created account
printf "Removing account %d\n", $account_id;
$params = SOAP::Data->name(parameters => { 
                                id => $account_id
						   });
$client->soap_call('delete_voip_account', $params);
print "Account was removed.\n";

exit 0;
1;
