#!/usr/bin/python
#----------------------------------------------------------------------
# SOAP client example, Sipwise GmbH, v1.0
#----------------------------------------------------------------------
from suds.client import Client
from suds.xsd.doctor import ImportDoctor, Import
from suds import null
from sys import exit

http_username = 'ngcpsoap'
http_password = 's04pt3st'
auth_username = 'administrator'
auth_password = 'administrator'
hostname      = '10.20.30.40'

print "SOAP client started."

# https connection
wsdl_url = 'https://' + hostname + ':2443/SOAP/Provisioning.wsdl'
imp = Import('http://schemas.xmlsoap.org/soap/encoding/')
doctor = ImportDoctor(imp)
client = Client(wsdl_url, 
                username=http_username, 
                password=http_password, 
                doctor=doctor)

# authentication
auth = client.factory.create('ns0:Authentication')
auth.username = auth_username
auth.password = auth_password
auth.type = 'admin'

# get domains
print "Fetching domains list."
domains = client.service.get_domains(auth)
if not len(domains):
    exit(1) 
for row in domains:
        print "domain: " + row.domain

# create a temporary account
print "Creating an account."
params = client.factory.create('ns0:CreateVoIPAccountParameter')
account_params = client.factory.create('ns0:VoipAccountCreate')
account_params.billing_profile = 'default'
params.data = account_params
account_id = client.service.create_voip_account(auth, params)
print "Created account: %d" % (account_id)

# create a temporary subscriber
subscriber_name = 'soaptest'
domain_name = domains[0].domain
print "Creating subscriber %s@%s" % (subscriber_name, domain_name)
subscriber_params = client.factory.create('ns0:WriteSubscriberParameter')
subscriber_params.id = account_id
subscriber_params.subscriber.username = subscriber_name
subscriber_params.subscriber.password = 'soaptest123456'
subscriber_params.subscriber.domain = domain_name
client.service.add_voip_account_subscriber(auth, subscriber_params)
print "Created subscriber %s@%s" % (subscriber_name, domain_name)

# get/set subscriber's preferences
print "-- subscriber's preferences set"
print "--   'ac' -> '43'"
print "--   'sst_enable' -> 'yes'"
subscriber_prefs = client.factory.create('ns0:SetSubscriberPreferencesParameter')
subscriber_prefs.username = subscriber_name
subscriber_prefs.domain = domain_name
subscriber_prefs.preferences.ac = 43
subscriber_prefs.preferences.sst_enable = 'yes' # use .sst_enable = null() if you want to set it to undefined/default
client.service.set_subscriber_preferences(auth, subscriber_prefs)

print "-- subscriber's preferences get"
subscriber = client.factory.create("ns0:UserDomParameter")
subscriber.username = subscriber_name
subscriber.domain = domain_name;
subscriber_prefs = client.service.get_subscriber_preferences(auth, subscriber)
print "-- ac: %s" % subscriber_prefs.ac
print "-- sst_enable: %s" % subscriber_prefs.sst_enable

# delete the created account
print "Removing account %d" % account_id
params = client.factory.create('ns0:AccountIdParameter')
params.id = account_id
client.service.delete_voip_account(auth, params)
print "Account was removed."

exit(0)
