#!/usr/bin/ruby
#----------------------------------------------------------------------
# SOAP client example, Sipwise GmbH, v1.0
#----------------------------------------------------------------------
require 'rubygems'
require 'savon'
gem 'savon', '~> 2.2.0'

puts "SOAP client started."

http_username = 'ngcpsoap'
http_password = 's04pt3st'
auth_username = 'administrator'
auth_password = 'administrator'
hostname      = '10.20.30.40'

client = Savon.client do 
    basic_auth http_username, http_password
    wsdl "https://" + hostname + ":2443/SOAP/Provisioning.wsdl"
    log_level :debug
    log false
    ssl_verify_mode :none
    strip_namespaces true
    convert_request_keys_to :none
    pretty_print_xml :true
end

# authentication
auth = { :username => auth_username,
         :password => auth_password,
         :type => 'admin'
        }

# get domains
puts "Fetching domains list."
domains_response = client.call :get_domains do 
    message :authentication => auth
end

domains = []
if domains_response.success?
    domains_response.to_hash[:get_domains_response][:data][:item].each_with_index do |key, i|
        puts "domain %d: %s" % [i+1, key[:domain]]
        domains.push(key[:domain])
    end
else
    raise "Error"
end

if domains.length == 0 
    exit 1
end

# create a temporary account
puts "Creating an account."
create_account = client.call :create_voip_account do 
    message :authentication => auth,
            :parameters => { 
                :data => { 
                    :billing_profile => 'default' 
                } 
            }
end

if create_account.success?
    account_id = create_account.to_hash[:create_voip_account_response][:data]
else
    raise "Error"
end
puts "Created account: %d" % [account_id]

# create a temporary subscriber
subscriber_name = "soaptest"
domain_name     = domains[0]
puts "Creating subscriber %s@%s" % [subscriber_name, domain_name]
response = client.call :add_voip_account_subscriber do 
    message :authentication => auth,
            :parameters => { 
                :id => account_id,
                :subscriber => { 
                    :username => subscriber_name,
                    :password => 'soaptest123456',
                    :domain   => domain_name
                }
            }
end

if response.success?
    puts "Created susbcriber %s@%s" % [subscriber_name, domain_name]
else
    raise "Error"
end

# get/set subscriber's preferences
puts "-- subscriber's preferences set"
puts "--   'ac' -> '43'"
puts "--   'sst_enable' -> 'yes'"
response = client.call :set_subscriber_preferences do
    message :authentication => auth,
            :parameters => {
                :username => subscriber_name,
                :domain   => domain_name,
                :preferences => { 
                    :ac => 43, # 
                    :sst_enable => 'yes' # nil - to set back to the domain value
                }
            }
end

if not response.success?
    #raise "Error"
end

puts "-- subscriber's preferences get"
preferences = client.call :get_subscriber_preferences do
    message :authentication => auth,
            :parameters => {
                             :username => subscriber_name,
                             :domain   => domain_name,
                           }
end

if preferences.success?
    subscriber_prefs = preferences.to_hash[:get_subscriber_preferences_response][:data]
    puts "-- ac: %s" % subscriber_prefs[:ac]
    puts "-- sst_enable: %s" % subscriber_prefs[:sst_enable] 
                               # @xsi:typetypens:sst_enable_usrEnum - means nil
else
    raise "Error"
end

# delete the created account
puts "Removing account %d" % account_id
delete_account = client.call :delete_voip_account do 
    message :authentication => auth,
            :parameters => { :id => account_id }
end

if delete_account.success? && account_id.to_i > 0
    puts "Account was removed."
else
    raise "Error"
end

exit 0
